==> bloonix-core-1.36.tar.gz: bloonix-core-1.36/tests/test_rx.py <==
#!/usr/bin/python3

import bloonix.rx as rx
import re
import unittest

class Testrx(unittest.TestCase):
    def test_year(self):
        for x in ["2016", "0", "-2016", "10000"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.YEAR_BASE, x))
            self.assertTrue(re.search(rx.YEAR, x))
        for x in ["2a0", "b"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.YEAR_BASE, x) is None)
            self.assertTrue(re.search(rx.YEAR, x) is None)

    def test_month(self):
        for x in list(map((lambda x: str("%02d" % x)), range(1, 12))):
            self.assertTrue(re.search(r"^%s\Z" % rx.MONTH_BASE, x))
            self.assertTrue(re.search(rx.MONTH, x))
        for x in ["1","2","3","4","5","6","7","8","9","0","13","foo"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.MONTH_BASE, x) is None)
            self.assertTrue(re.search(rx.MONTH, x) is None)

    def test_day(self):
        for x in list(map((lambda x: str("%02d" % x)), range(1, 32))):
            self.assertTrue(re.search(r"^%s\Z" % rx.DAY_BASE, x))
            self.assertTrue(re.search(rx.DAY, x))
        for x in ["1","2","3","4","5","6","7","8","9","0","32","foo"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.DAY_BASE, x) is None)
            self.assertTrue(re.search(rx.DAY, x) is None)

    def test_month_name(self):
        for x in ["January","February","March","April","May","June","July",
                "August","September","October","November","December",
                "Jan","Feb","Mar","Apr","Jun","Jul","Aug","Sep","Oct","Nov","Dec"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.MONTH_NAME_BASE, x))
            self.assertTrue(re.search(rx.MONTH_NAME, x))

    def test_hour(self):
        for x in list(map((lambda x: str("%02d" % x)), range(0, 24))):
            self.assertTrue(re.search(r"^%s\Z" % rx.HOUR_BASE, x))
            self.assertTrue(re.search(rx.HOUR, x))
        for x in ["1","2","3","4","5","6","7","8","9","0","24"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.HOUR_BASE, x) is None)
            self.assertTrue(re.search(rx.HOUR, x) is None)

    def test_min_sec(self):
        for x in list(map((lambda x: str("%02d" % x)), range(0, 60))):
            self.assertTrue(re.search(r"^%s\Z" % rx.MINUTE_BASE, x))
            self.assertTrue(re.search(r"^%s\Z" % rx.SECOND_BASE, x))
            self.assertTrue(re.search(rx.MINUTE, x))
            self.assertTrue(re.search(rx.SECOND, x))
        for x in ["1","2","3","4","5","6","7","8","9","0","60"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.MINUTE_BASE, x) is None)
            self.assertTrue(re.search(r"^%s\Z" % rx.SECOND_BASE, x) is None)
            self.assertTrue(re.search(rx.MINUTE, x) is None)
            self.assertTrue(re.search(rx.SECOND, x) is None)

    def test_datetime(self):
        self.assertTrue(re.search(rx.DATETIME, "2016-01-01 00:00:00"))
        self.assertTrue(re.search(rx.DATETIME, "0-01-01 00:00:00"))
        self.assertTrue(re.search(rx.DATETIME, "0-01-01 61:00:00") is None)
        self.assertTrue(re.search(rx.DATETIME, "0-01-01 00:61:00") is None)
        self.assertTrue(re.search(rx.DATETIME, "0-01-01 00:00:61") is None)
        self.assertTrue(re.search(rx.DATETIME, "0-13-01 00:00:00") is None)
        self.assertTrue(re.search(rx.DATETIME, "0-01-32 00:00:00") is None)

    def test_date(self):
        self.assertTrue(re.search(rx.DATE, "2016-01-01"))
        self.assertTrue(re.search(rx.DATE, "0-01-01"))
        self.assertTrue(re.search(rx.DATE, "0-13-01") is None)
        self.assertTrue(re.search(rx.DATE, "0-01-32") is None)

    def test_time(self):
        self.assertTrue(re.search(rx.TIME, "00:00:00"))
        self.assertTrue(re.search(rx.TIME, "61:00:00") is None)
        self.assertTrue(re.search(rx.TIME, "00:61:00") is None)
        self.assertTrue(re.search(rx.TIME, "00:00:61") is None)
        self.assertTrue(re.search(rx.TIME, "0:0:0") is None)

    def test_ipv4(self):
        self.assertTrue(re.search(rx.IPV4, "0.0.0.0"))
        self.assertTrue(re.search(rx.IPV4, "001.001.001.001"))
        self.assertTrue(re.search(rx.IPV4, "000.000.000.000"))
        self.assertTrue(re.search(rx.IPV4, "255.255.255.255"))
        self.assertTrue(re.search(rx.IPV4, "255.255.255.256") is None)

    def test_ipv4net(self):
        for x in list(map((lambda x: str(x)), range(0, 33))):
            self.assertTrue(re.search(rx.IPV4NET, "0.0.0.0/%s" % x))
        self.assertTrue(re.search(rx.IPV4NET, "0.0.0.0/33") is None)
        self.assertTrue(re.search(rx.IPV4NET, "0.0.0.0") is None)

    def test_ipv4(self):
        self.assertTrue(re.search(rx.IPV6, "::0"))
        self.assertTrue(re.search(rx.IPV6, "0000:0000:0000:0000:0000:0000:0000:0000"))
        self.assertTrue(re.search(rx.IPV6, "12af:12af::12af"))
        self.assertTrue(re.search(rx.IPV6, "12ag:12af::12af") is None)
        self.assertTrue(re.search(rx.IPV6, "12ag:12af::12345") is None)

    def test_ipv4net(self):
        for x in list(map((lambda x: str(x)), range(0, 129))):
            self.assertTrue(re.search(rx.IPV6NET, "::1/%s" % x))
        self.assertTrue(re.search(rx.IPV6NET, "::1/129") is None)

    def test_hostname(self):
        self.assertTrue(re.search(rx.HOSTNAME, "test.test"))
        self.assertTrue(re.search(rx.HOSTNAME, "123test.123test"))
        self.assertTrue(re.search(rx.HOSTNAME, "test-test"))
        self.assertTrue(re.search(rx.HOSTNAME, "test..test") is None)
        self.assertTrue(re.search(rx.HOSTNAME, "test--test") is None)

    def test_url(self):
        self.assertTrue(re.search(rx.HTTP_URL, "https://test.test"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://123test.123test"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test-test"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test.test:443"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://123test.123test:443"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test-test:443"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://test.test"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://123test.123test"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://test-test"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://test.test:443"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://123test.123test:443"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://test-test:443"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test..test") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test--test") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "http://test..test") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "http://test--test") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test-test:443:80") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "http://test-test:443:80") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test'test") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test`test") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test.test/?a=b'c=d") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test.test/?a=b`c=d") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test.test/?a=b"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://123test.123test/?a=b"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test-test/?a=b"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test.test:443/?a=b"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://123test.123test:443/?a=b"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test-test:443/?a=b"))

    def test_email(self):
        self.assertTrue(re.search(rx.EMAIL, "test@test.test"))
        self.assertTrue(re.search(rx.EMAIL, "test-test@test.test"))
        self.assertTrue(re.search(rx.EMAIL, "test.test@test.test"))
        self.assertTrue(re.search(rx.EMAIL, "test+test@test.test"))
        self.assertTrue(re.search(rx.EMAIL, "test,test@test.test") is None)


unittest.main(verbosity=2)

==> bloonix-core-1.45.tar.gz: bloonix-core-1.45/tests/test_rx.py <==
#!/usr/bin/python3

import bloonix.rx as rx
import re
import unittest

class Testrx(unittest.TestCase):
    def test_year(self):
        for x in ["2016", "0", "-2016", "10000"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.YEAR_BASE, x))
            self.assertTrue(re.search(rx.YEAR, x))
        for x in ["2a0", "b"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.YEAR_BASE, x) is None)
            self.assertTrue(re.search(rx.YEAR, x) is None)

    def test_month(self):
        for x in list(map((lambda x: str("%02d" % x)), range(1, 12))):
            self.assertTrue(re.search(r"^%s\Z" % rx.MONTH_BASE, x))
            self.assertTrue(re.search(rx.MONTH, x))
        for x in ["1","2","3","4","5","6","7","8","9","0","13","foo"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.MONTH_BASE, x) is None)
            self.assertTrue(re.search(rx.MONTH, x) is None)

    def test_day(self):
        for x in list(map((lambda x: str("%02d" % x)), range(1, 32))):
            self.assertTrue(re.search(r"^%s\Z" % rx.DAY_BASE, x))
            self.assertTrue(re.search(rx.DAY, x))
        for x in ["1","2","3","4","5","6","7","8","9","0","32","foo"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.DAY_BASE, x) is None)
            self.assertTrue(re.search(rx.DAY, x) is None)

    def test_month_name(self):
        for x in ["January","February","March","April","May","June","July",
                "August","September","October","November","December",
                "Jan","Feb","Mar","Apr","Jun","Jul","Aug","Sep","Oct","Nov","Dec"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.MONTH_NAME_BASE, x))
            self.assertTrue(re.search(rx.MONTH_NAME, x))

    def test_hour(self):
        for x in list(map((lambda x: str("%02d" % x)), range(0, 24))):
            self.assertTrue(re.search(r"^%s\Z" % rx.HOUR_BASE, x))
            self.assertTrue(re.search(rx.HOUR, x))
        for x in ["1","2","3","4","5","6","7","8","9","0","24"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.HOUR_BASE, x) is None)
            self.assertTrue(re.search(rx.HOUR, x) is None)

    def test_min_sec(self):
        for x in list(map((lambda x: str("%02d" % x)), range(0, 60))):
            self.assertTrue(re.search(r"^%s\Z" % rx.MINUTE_BASE, x))
            self.assertTrue(re.search(r"^%s\Z" % rx.SECOND_BASE, x))
            self.assertTrue(re.search(rx.MINUTE, x))
            self.assertTrue(re.search(rx.SECOND, x))
        for x in ["1","2","3","4","5","6","7","8","9","0","60"]:
            self.assertTrue(re.search(r"^%s\Z" % rx.MINUTE_BASE, x) is None)
            self.assertTrue(re.search(r"^%s\Z" % rx.SECOND_BASE, x) is None)
            self.assertTrue(re.search(rx.MINUTE, x) is None)
            self.assertTrue(re.search(rx.SECOND, x) is None)

    def test_datetime(self):
        self.assertTrue(re.search(rx.DATETIME, "2016-01-01 00:00:00"))
        self.assertTrue(re.search(rx.DATETIME, "0-01-01 00:00:00"))
        self.assertTrue(re.search(rx.DATETIME, "0-01-01 61:00:00") is None)
        self.assertTrue(re.search(rx.DATETIME, "0-01-01 00:61:00") is None)
        self.assertTrue(re.search(rx.DATETIME, "0-01-01 00:00:61") is None)
        self.assertTrue(re.search(rx.DATETIME, "0-13-01 00:00:00") is None)
        self.assertTrue(re.search(rx.DATETIME, "0-01-32 00:00:00") is None)

    def test_date(self):
        self.assertTrue(re.search(rx.DATE, "2016-01-01"))
        self.assertTrue(re.search(rx.DATE, "0-01-01"))
        self.assertTrue(re.search(rx.DATE, "0-13-01") is None)
        self.assertTrue(re.search(rx.DATE, "0-01-32") is None)

    def test_time(self):
        self.assertTrue(re.search(rx.TIME, "00:00:00"))
        self.assertTrue(re.search(rx.TIME, "61:00:00") is None)
        self.assertTrue(re.search(rx.TIME, "00:61:00") is None)
        self.assertTrue(re.search(rx.TIME, "00:00:61") is None)
        self.assertTrue(re.search(rx.TIME, "0:0:0") is None)

    def test_ipv4(self):
        self.assertTrue(re.search(rx.IPV4, "0.0.0.0"))
        self.assertTrue(re.search(rx.IPV4, "001.001.001.001"))
        self.assertTrue(re.search(rx.IPV4, "000.000.000.000"))
        self.assertTrue(re.search(rx.IPV4, "255.255.255.255"))
        self.assertTrue(re.search(rx.IPV4, "255.255.255.256") is None)

    def test_ipv4net(self):
        for x in list(map((lambda x: str(x)), range(0, 33))):
            self.assertTrue(re.search(rx.IPV4NET, "0.0.0.0/%s" % x))
        self.assertTrue(re.search(rx.IPV4NET, "0.0.0.0/33") is None)
        self.assertTrue(re.search(rx.IPV4NET, "0.0.0.0") is None)

    def test_ipv4(self):
        self.assertTrue(re.search(rx.IPV6, "::0"))
        self.assertTrue(re.search(rx.IPV6, "0000:0000:0000:0000:0000:0000:0000:0000"))
        self.assertTrue(re.search(rx.IPV6, "12af:12af::12af"))
        self.assertTrue(re.search(rx.IPV6, "12ag:12af::12af") is None)
        self.assertTrue(re.search(rx.IPV6, "12ag:12af::12345") is None)

    def test_ipv4net(self):
        for x in list(map((lambda x: str(x)), range(0, 129))):
            self.assertTrue(re.search(rx.IPV6NET, "::1/%s" % x))
        self.assertTrue(re.search(rx.IPV6NET, "::1/129") is None)

    def test_hostname(self):
        self.assertTrue(re.search(rx.HOSTNAME, "test.test"))
        self.assertTrue(re.search(rx.HOSTNAME, "123test.123test"))
        self.assertTrue(re.search(rx.HOSTNAME, "test-test"))
        self.assertTrue(re.search(rx.HOSTNAME, "test..test") is None)
        self.assertTrue(re.search(rx.HOSTNAME, "test--test"))

    def test_url(self):
        self.assertTrue(re.search(rx.HTTP_URL, "https://test.test"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://123test.123test"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test-test"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test.test:443"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://123test.123test:443"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test-test:443"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://test.test"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://123test.123test"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://test-test"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://test.test:443"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://123test.123test:443"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://test-test:443"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test..test") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test--test"))
        self.assertTrue(re.search(rx.HTTP_URL, "http://test..test") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "http://test--test"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test-test:443:80") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "http://test-test:443:80") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test'test") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test`test") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test.test/?a=b'c=d") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test.test/?a=b`c=d") is None)
        self.assertTrue(re.search(rx.HTTP_URL, "https://test.test/?a=b"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://123test.123test/?a=b"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test-test/?a=b"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test.test:443/?a=b"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://123test.123test:443/?a=b"))
        self.assertTrue(re.search(rx.HTTP_URL, "https://test-test:443/?a=b"))

    def test_email(self):
        self.assertTrue(re.search(rx.EMAIL, "test@test.test"))
        self.assertTrue(re.search(rx.EMAIL, "test-test@test.test"))
        self.assertTrue(re.search(rx.EMAIL, "test.test@test.test"))
        self.assertTrue(re.search(rx.EMAIL, "test+test@test.test"))
        self.assertTrue(re.search(rx.EMAIL, "test,test@test.test") is None)


unittest.main(verbosity=2)
